@@ -25,6 +25,8 @@
 #'   an "uncertainty" or "compatibility" interval, the latter being defined as
 #'   \dQuote{Given any value in the interval and the background assumptions,
 #'   the data should not seem very surprising} (\cite{Gelman & Greenland 2019}).
+#'   \cr \cr
+#'   There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @references Gelman A, Greenland S. Are confidence intervals better termed "uncertainty intervals"? BMJ 2019;l5381. \doi{10.1136/bmj.l5381}
 #'
@@ -38,7 +40,6 @@
 #' df <- data.frame(replicate(4, rnorm(100)))
 #' ci(df, method = "ETI", ci = c(.80, .89, .95))
 #' ci(df, method = "HDI", ci = c(.80, .89, .95))
-#'
 #' \dontrun{
 #' if (require("rstanarm")) {
 #'   model <- stan_glm(mpg ~ wt, data = mtcars, chains = 2, iter = 200, refresh = 0)
@@ -98,9 +99,27 @@ ci.numeric <- function(x, ci = .89, method = "ETI", verbose = TRUE, BF = 1, ...)
 #' @export
 ci.data.frame <- ci.numeric
 
-#' @rdname ci
+
+
 #' @export
-ci.emmGrid <- ci.numeric
+ci.emmGrid <- function(x, ci = NULL, ...) {
+  if (!.is_baysian_emmeans(x)) {
+    if (!requireNamespace("parameters")) {
+      stop("'parameters' required for this function to work.")
+    }
+
+    if (is.null(ci)) ci <- 0.95
+    return(parameters::ci_wald(model = x, ci = ci, dof = parameters::degrees_of_freedom(x), ...))
+  }
+
+  if (is.null(ci)) ci <- 0.89
+  x <- insight::get_parameters(x)
+  ci(x, ci = ci, ...)
+}
+
+
+#' @export
+ci.emm_list <- ci.emmGrid
 
 
 
@@ -124,8 +143,9 @@ ci.sim <- function(x, ci = .89, method = "ETI", parameters = NULL, verbose = TRU
 #' @rdname ci
 #' @export
 ci.stanreg <- function(x, ci = .89, method = "ETI", effects = c("fixed", "random", "all"),
-                       parameters = NULL, verbose = TRUE,  BF = 1,...) {
-  .ci_bayesian(x, ci = ci, method = method, effects = effects, parameters = parameters, verbose = verbose, BF = BF, ...)
+                       component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
+                       parameters = NULL, verbose = TRUE, BF = 1, ...) {
+  .ci_bayesian(x, ci = ci, method = method, effects = effects, component = component, parameters = parameters, verbose = verbose, BF = BF, ...)
 }
 
 
@@ -138,6 +158,10 @@ ci.brmsfit <- function(x, ci = .89, method = "ETI", effects = c("fixed", "random
 }
 
 
+#' @export
+ci.stanfit <- ci.stanreg
+
+
 #' @rdname ci
 #' @export
 ci.BFBayesFactor <- ci.numeric
@@ -158,3 +182,24 @@ ci.MCMCglmm <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
 ci.mcmc <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
   ci(as.data.frame(x), ci = ci, method = method, verbose = verbose, ...)
 }
+
+
+
+#' @export
+ci.bamlss <- function(x, ci = .89, method = "ETI", component = c("all", "conditional", "location"), verbose = TRUE, ...) {
+  component <- match.arg(component)
+  ci(insight::get_parameters(x, component = component), ci = ci, method = method, verbose = verbose, ...)
+}
+
+
+
+#' @export
+ci.bcplm <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
+  ci(insight::get_parameters(x), ci = ci, method = method, verbose = verbose, ...)
+}
+
+
+#' @export
+ci.mcmc.list <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
+  ci(insight::get_parameters(x), ci = ci, method = method, verbose = verbose, ...)
+}
