@@ -2,8 +2,9 @@
 #'
 #' Compute the \strong{Highest Density Interval (HDI)} of posterior distributions. All points within this interval have a higher probability density than points outside the interval. The HDI can be used in the context of uncertainty characterisation of posterior distributions as \strong{Credible Interval (CI)}.
 #'
-#' @param x Vector representing a posterior distribution. Can also be a
-#'   \code{stanreg}, \code{brmsfit} or a \code{BayesFactor} model.
+#' @param x Vector representing a posterior distribution, or a data frame of such
+#'   vectors. Can also be a Bayesian model (\code{stanreg}, \code{brmsfit},
+#'   \code{MCMCglmm}, \code{mcmc} or \code{bcplm}) or a \code{BayesFactor} model.
 #' @param ci Value or vector of probability of the (credible) interval - CI (between 0 and 1)
 #'   to be estimated. Default to \code{.89} (89\%).
 #' @param effects Should results for fixed effects, random effects or both be returned?
@@ -19,7 +20,7 @@
 #' @param verbose Toggle off warnings.
 #' @param ... Currently not used.
 #'
-#'
+#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @details Unlike equal-tailed intervals (see \code{eti()}) that typically exclude 2.5\%
 #' from each tail of the distribution and always include the median, the HDI is
@@ -63,7 +64,6 @@
 #' df <- data.frame(replicate(4, rnorm(100)))
 #' hdi(df)
 #' hdi(df, ci = c(.80, .90, .95))
-#'
 #' \dontrun{
 #' library(rstanarm)
 #' model <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200, refresh = 0)
@@ -83,7 +83,6 @@
 #' hdi(bf)
 #' hdi(bf, ci = c(.80, .90, .95))
 #' }
-#'
 #' @author Credits go to \href{https://rdrr.io/cran/ggdistribute/src/R/stats.R}{ggdistribute} and \href{https://github.com/mikemeredith/HDInterval}{HDInterval}.
 #'
 #' @references \itemize{
@@ -121,6 +120,9 @@ hdi.data.frame <- function(x, ci = .89, verbose = TRUE, ...) {
 
 
 
+
+
+
 #' @rdname hdi
 #' @export
 hdi.MCMCglmm <- function(x, ci = .89, verbose = TRUE, ...) {
@@ -133,6 +135,17 @@ hdi.MCMCglmm <- function(x, ci = .89, verbose = TRUE, ...) {
 
 
 
+#' @export
+hdi.bamlss <- function(x, ci = .89, component = c("all", "conditional", "location"), verbose = TRUE, ...) {
+  component <- match.arg(component)
+  d <- insight::get_parameters(x, component = component)
+  dat <- .compute_interval_dataframe(x = d, ci = ci, verbose = verbose, fun = "hdi")
+  attr(dat, "data") <- .safe_deparse(substitute(x))
+  dat
+}
+
+
+
 #' @export
 hdi.mcmc <- function(x, ci = .89, verbose = TRUE, ...) {
   d <- as.data.frame(x)
@@ -143,6 +156,23 @@ hdi.mcmc <- function(x, ci = .89, verbose = TRUE, ...) {
 
 
 
+#' @export
+hdi.bcplm <- function(x, ci = .89, verbose = TRUE, ...) {
+  d <- insight::get_parameters(x)
+  dat <- .compute_interval_dataframe(x = d, ci = ci, verbose = verbose, fun = "hdi")
+  attr(dat, "data") <- .safe_deparse(substitute(x))
+  dat
+}
+
+
+#' @rdname hdi
+#' @export
+hdi.bayesQR <- hdi.bcplm
+
+#' @export
+hdi.mcmc.list <- hdi.bcplm
+
+
 #' @rdname hdi
 #' @export
 hdi.sim.merMod <- function(x, ci = .89, effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
@@ -169,26 +199,29 @@ hdi.sim <- function(x, ci = .89, parameters = NULL, verbose = TRUE, ...) {
 #' @rdname hdi
 #' @export
 hdi.emmGrid <- function(x, ci = .89, verbose = TRUE, ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
-  }
-  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+  xdf <- insight::get_parameters(x)
+
   out <- hdi(xdf, ci = ci, verbose = verbose, ...)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
+#' @export
+hdi.emm_list <- hdi.emmGrid
+
 
 
 #' @importFrom insight get_parameters
 #' @rdname hdi
 #' @export
-hdi.stanreg <- function(x, ci = .89, effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
+hdi.stanreg <- function(x, ci = .89, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
+  component <- match.arg(component)
 
   out <- .prepare_output(
-    hdi(insight::get_parameters(x, effects = effects, parameters = parameters), ci = ci, verbose = verbose, ...),
-    insight::clean_parameters(x)
+    hdi(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), ci = ci, verbose = verbose, ...),
+    insight::clean_parameters(x),
+    inherits(x, "stanmvreg")
   )
 
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -196,6 +229,9 @@ hdi.stanreg <- function(x, ci = .89, effects = c("fixed", "random", "all"), para
   out
 }
 
+#' @export
+hdi.stanfit <- hdi.stanreg
+
 
 
 #' @rdname hdi
@@ -215,6 +251,7 @@ hdi.brmsfit <- function(x, ci = .89, effects = c("fixed", "random", "all"), comp
 }
 
 
+
 #' @rdname hdi
 #' @export
 hdi.BFBayesFactor <- function(x, ci = .89, verbose = TRUE, ...) {
@@ -240,7 +277,7 @@ hdi.BFBayesFactor <- function(x, ci = .89, verbose = TRUE, ...) {
       warning("`ci` is too small or x does not contain enough data points, returning NAs.")
     }
     return(data.frame(
-      "CI" = ci * 100,
+      "CI" = ci,
       "CI_low" = NA,
       "CI_high" = NA
     ))
@@ -253,7 +290,7 @@ hdi.BFBayesFactor <- function(x, ci = .89, verbose = TRUE, ...) {
       warning("`ci` is too large or x does not contain enough data points, returning NAs.")
     }
     return(data.frame(
-      "CI" = ci * 100,
+      "CI" = ci,
       "CI_low" = NA,
       "CI_high" = NA
     ))
@@ -277,7 +314,7 @@ hdi.BFBayesFactor <- function(x, ci = .89, verbose = TRUE, ...) {
   }
 
   data.frame(
-    "CI" = ci * 100,
+    "CI" = ci,
     "CI_low" = x_sorted[min_i],
     "CI_high" = x_sorted[min_i + window_size]
   )
