@@ -1,6 +1,19 @@
 #' Probability of Direction (pd)
 #'
-#' Compute the \strong{Probability of Direction} (\strong{\emph{pd}}, also known as the Maximum Probability of Effect - \emph{MPE}). It varies between 50\% and 100\% (\emph{i.e.}, \code{0.5} and \code{1}) and can be interpreted as the probability (expressed in percentage) that a parameter (described by its posterior distribution) is strictly positive or negative (whichever is the most probable). It is mathematically defined as the proportion of the posterior distribution that is of the median's sign. Altough differently expressed, this index is fairly similar (\emph{i.e.}, is strongly correlated) to the frequentist \strong{p-value}.
+#' Compute the \strong{Probability of Direction} (\strong{\emph{pd}}, also known
+#' as the Maximum Probability of Effect - \emph{MPE}). It varies between 50\%
+#' and 100\% (\emph{i.e.}, \code{0.5} and \code{1}) and can be interpreted as
+#' the probability (expressed in percentage) that a parameter (described by its
+#' posterior distribution) is strictly positive or negative (whichever is the
+#' most probable). It is mathematically defined as the proportion of the
+#' posterior distribution that is of the median's sign. Although differently
+#' expressed, this index is fairly similar (\emph{i.e.}, is strongly correlated)
+#' to the frequentist \strong{p-value}.
+#' \cr\cr
+#' Note that in some (rare) cases, especially when used with model averaged
+#' posteriors (see \code{\link{weighted_posteriors}} or
+#' \code{brms::posterior_average}), \code{pd} can be smaller than \code{0.5},
+#' reflecting high credibility of \code{0}.
 #'
 #' @param x Vector representing a posterior distribution. Can also be a Bayesian model (\code{stanreg}, \code{brmsfit} or \code{BayesFactor}).
 #' @param method Can be \code{"direct"} or one of methods of \link[=estimate_density]{density estimation}, such as \code{"kernel"}, \code{"logspline"} or \code{"KernSmooth"}. If \code{"direct"} (default), the computation is based on the raw ratio of samples superior and inferior to 0. Else, the result is based on the \link[=auc]{Area under the Curve (AUC)} of the estimated \link[=estimate_density]{density} function.
@@ -16,10 +29,10 @@
 #' }
 #' }
 #' \subsection{Relationship with the p-value}{
-#' In most cases, it seems that the \emph{pd} has a direct correspondance with the frequentist one-sided \emph{p}-value through the formula \ifelse{html}{\out{p<sub>one&nbsp;sided</sub>&nbsp;=&nbsp;1&nbsp;-&nbsp;<sup>p(<em>d</em>)</sup>/<sub>100</sub>}}{\eqn{p_{one sided}=1-\frac{p_{d}}{100}}} and to the two-sided p-value (the most commonly reported one) through the formula \ifelse{html}{\out{p<sub>two&nbsp;sided</sub>&nbsp;=&nbsp;2&nbsp;*&nbsp;(1&nbsp;-&nbsp;<sup>p(<em>d</em>)</sup>/<sub>100</sub>)}}{\eqn{p_{two sided}=2*(1-\frac{p_{d}}{100})}}. Thus, a two-sided p-value of respectively \code{.1}, \code{.05}, \code{.01} and \code{.001} would correspond approximately to a \emph{pd} of 95\%, 97.5\%, 99.5\% and 99.95\%.
+#' In most cases, it seems that the \emph{pd} has a direct correspondence with the frequentist one-sided \emph{p}-value through the formula \ifelse{html}{\out{p<sub>one&nbsp;sided</sub>&nbsp;=&nbsp;1&nbsp;-&nbsp;<sup>p(<em>d</em>)</sup>/<sub>100</sub>}}{\eqn{p_{one sided}=1-\frac{p_{d}}{100}}} and to the two-sided p-value (the most commonly reported one) through the formula \ifelse{html}{\out{p<sub>two&nbsp;sided</sub>&nbsp;=&nbsp;2&nbsp;*&nbsp;(1&nbsp;-&nbsp;<sup>p(<em>d</em>)</sup>/<sub>100</sub>)}}{\eqn{p_{two sided}=2*(1-\frac{p_{d}}{100})}}. Thus, a two-sided p-value of respectively \code{.1}, \code{.05}, \code{.01} and \code{.001} would correspond approximately to a \emph{pd} of 95\%, 97.5\%, 99.5\% and 99.95\%. See also \code{\link{pd_to_p}}.
 #' }
 #' \subsection{Methods of computation}{
-#'  The most simple and direct way to compute the \emph{pd} is to 1) look at the median's sign, 2) select the portion of the posterior of the same sign and 3) compute the percentage that this portion represents. This "simple" method is the most straigtfoward, but its precision is directly tied to the number of posterior draws. The second approach relies on \link[=estimate_density]{density estimation}. It starts by estimating the density function (for which many methods are available), and then computing the \link[=area_under_curve]{area under the curve} (AUC) of the density curve on the other side of 0.
+#'  The most simple and direct way to compute the \emph{pd} is to 1) look at the median's sign, 2) select the portion of the posterior of the same sign and 3) compute the percentage that this portion represents. This "simple" method is the most straightforward, but its precision is directly tied to the number of posterior draws. The second approach relies on \link[=estimate_density]{density estimation}. It starts by estimating the density function (for which many methods are available), and then computing the \link[=area_under_curve]{area under the curve} (AUC) of the density curve on the other side of 0.
 #' }
 #' \subsection{Strengths and Limitations}{
 #' \strong{Strengths:} Straightforward computation and interpretation. Objective property of the posterior distribution. 1:1 correspondence with the frequentist p-value.
@@ -27,7 +40,18 @@
 #' \strong{Limitations:} Limited information favoring the null hypothesis.
 #' }
 #'
-#' @return Values between 0.5 and 1 corresponding to the probability of direction (pd).
+#' @return
+#' Values between 0.5 and 1 corresponding to the probability of direction (pd).
+#' \cr\cr
+#' Note that in some (rare) cases, especially when used with model averaged
+#' posteriors (see \code{\link{weighted_posteriors}} or
+#' \code{brms::posterior_average}), \code{pd} can be smaller than \code{0.5},
+#' reflecting high credibility of \code{0}. To detect such cases, the
+#' \code{method = "direct"} must be used.
+#'
+#' @seealso \code{\link{pd_to_p}} to convert between Probability of Direction (pd) and p-value.
+#'
+#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @references Makowski D, Ben-Shachar MS, Chen SHA, Lüdecke D (2019) Indices of Effect Existence and Significance in the Bayesian Framework. Frontiers in Psychology 2019;10:2767. \doi{10.3389/fpsyg.2019.02767}
 #'
@@ -45,7 +69,6 @@
 #' df <- data.frame(replicate(4, rnorm(100)))
 #' p_direction(df)
 #' p_direction(df, method = "kernel")
-#'
 #' \dontrun{
 #' # rstanarm models
 #' # -----------------------------------------------
@@ -129,6 +152,7 @@ p_direction.numeric <- function(x, method = "direct", ...) {
 #' @rdname p_direction
 #' @export
 p_direction.data.frame <- function(x, method = "direct", ...) {
+  obj_name <- .safe_deparse(substitute(x))
   x <- .select_nums(x)
 
   if (ncol(x) == 1) {
@@ -144,7 +168,7 @@ p_direction.data.frame <- function(x, method = "direct", ...) {
     stringsAsFactors = FALSE
   )
 
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- obj_name
   class(out) <- unique(c("p_direction", "see_p_direction", class(out)))
 
   out
@@ -167,18 +191,44 @@ p_direction.mcmc <- function(x, method = "direct", ...) {
 }
 
 
+#' @export
+p_direction.bcplm <- function(x, method = "direct", ...) {
+  p_direction(insight::get_parameters(x), method = method, ...)
+}
+
+
+#' @export
+p_direction.mcmc.list <- function(x, method = "direct", ...) {
+  p_direction(insight::get_parameters(x), method = method, ...)
+}
+
+
+#' @export
+p_direction.bamlss <- function(x, method = "direct", component = c("all", "conditional", "location"), ...) {
+  component <- match.arg(component)
+  p_direction(insight::get_parameters(x, component = component), method = method, ...)
+}
+
+
+#' @export
+p_direction.bayesQR <- function(x, method = "direct", ...) {
+  p_direction(insight::get_parameters(x, method = method), ...)
+}
+
+
 #' @rdname p_direction
 #' @export
 p_direction.emmGrid <- function(x, method = "direct", ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
-  }
-  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+  xdf <- insight::get_parameters(x)
+
   out <- p_direction(xdf, method = method, ...)
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
   out
 }
 
+#' @export
+p_direction.emm_list <- p_direction.emmGrid
+
 #' @importFrom insight get_parameters
 #' @keywords internal
 .p_direction_models <- function(x, effects, component, parameters, method = "direct", ...) {
@@ -221,12 +271,14 @@ p_direction.sim <- function(x, parameters = NULL, method = "direct", ...) {
 
 #' @rdname p_direction
 #' @export
-p_direction.stanreg <- function(x, effects = c("fixed", "random", "all"), parameters = NULL, method = "direct", ...) {
+p_direction.stanreg <- function(x, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, method = "direct", ...) {
   effects <- match.arg(effects)
+  component <- match.arg(component)
 
   out <- .prepare_output(
-    p_direction(insight::get_parameters(x, effects = effects, parameters = parameters), method = method, ...),
-    insight::clean_parameters(x)
+    p_direction(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), method = method, ...),
+    insight::clean_parameters(x),
+    inherits(x, "stanmvreg")
   )
 
   class(out) <- unique(c("p_direction", "see_p_direction", class(out)))
@@ -234,6 +286,9 @@ p_direction.stanreg <- function(x, effects = c("fixed", "random", "all"), parame
   out
 }
 
+#' @export
+p_direction.stanfit <- p_direction.stanreg
+
 
 #' @rdname p_direction
 #' @export
