@@ -1,6 +1,6 @@
-#' Probability of not being in ROPE
+#' Probability of being in the ROPE
 #'
-#' Compute the proportion of the posterior distribution that doesn't lie within a region of practical equivalence (ROPE). It is equivalent to running \code{rope(..., ci = 1)}.
+#' Compute the proportion of the whole posterior distribution that doesn't lie within a region of practical equivalence (ROPE). It is equivalent to running \code{rope(..., ci = 1)}.
 #'
 #' @inheritParams rope
 #'
@@ -45,7 +45,16 @@ p_rope.data.frame <- p_rope.numeric
 
 #' @rdname p_rope
 #' @export
-p_rope.emmGrid <- p_rope.numeric
+p_rope.emmGrid <- function(x, range = "default", ...) {
+  xdf <- insight::get_parameters(x)
+
+  out <- p_rope(xdf, range = range)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  out
+}
+
+#' @export
+p_rope.emm_list <- p_rope.emmGrid
 
 #' @rdname p_rope
 #' @export
@@ -58,12 +67,14 @@ p_rope.MCMCglmm <- p_rope.numeric
 
 #' @rdname p_rope
 #' @export
-p_rope.stanreg <- function(x, range = "default", effects = c("fixed", "random", "all"), parameters = NULL, ...) {
-  out <- .p_rope(rope(x, range = range, ci = 1, effects = effects, parameters = parameters, ...))
+p_rope.stanreg <- function(x, range = "default", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
+  out <- .p_rope(rope(x, range = range, ci = 1, effects = effects, component = component, parameters = parameters, ...))
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
+#' @export
+p_rope.stanfit <- p_rope.stanreg
 
 
 #' @rdname p_rope
@@ -86,6 +97,14 @@ p_rope.sim <- function(x, range = "default", parameters = NULL, ...) {
   out
 }
 
+#' @export
+p_rope.bamlss <- function(x, range = "default", component = c("all", "conditional", "location"), parameters = NULL, ...) {
+  component <- match.arg(component)
+  out <- .p_rope(rope(x, range = range, ci = 1, effects = "all", component = component, parameters = parameters, ...))
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  out
+}
+
 #' @export
 p_rope.mcmc <- function(x, range = "default", parameters = NULL, ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, parameters = parameters, ...))
@@ -93,6 +112,11 @@ p_rope.mcmc <- function(x, range = "default", parameters = NULL, ...) {
   out
 }
 
+#' @export
+p_rope.bcplm <- p_rope.mcmc
+
+#' @export
+p_rope.mcmc.list <- p_rope.mcmc
 
 
 
@@ -107,4 +131,4 @@ p_rope.mcmc <- function(x, range = "default", parameters = NULL, ...) {
 
   class(out) <- c("p_rope", "see_p_rope", "data.frame")
   out
-}
\ No newline at end of file
+}
