@@ -1,5 +1,6 @@
 #' @export
 print.mhdior <- function(x, digits = 2, ...) {
+  orig_x <- x
   if ("data_plot" %in% class(x)) {
     print(as.data.frame(x))
   } else if ("data.frame" %in% class(x)) {
@@ -8,4 +9,5 @@ print.mhdior <- function(x, digits = 2, ...) {
   } else {
     cat(sprintf("MHDIOR = %.*f%%", digits, x * 100))
   }
+  invisible(orig_x)
 }
