@@ -1,5 +1,6 @@
 #' @export
 print.p_map <- function(x, digits = 3, ...) {
+  orig_x <- x
   if ("data_plot" %in% class(x)) {
     print(as.data.frame(x))
   } else if ("data.frame" %in% class(x)) {
@@ -8,4 +9,5 @@ print.p_map <- function(x, digits = 3, ...) {
   } else {
     cat(sprintf("p (MAP) = %.*f", digits, x))
   }
+  invisible(orig_x)
 }
