@@ -22,6 +22,8 @@ print_data_frame <- function(x, digits) {
       "conditional" = ,
       "fixed_conditional" = ,
       "fixed" = "# Fixed Effects (Conditional Model)",
+      "fixed_sigma" = "# Sigma (fixed effects)",
+      "sigma" = "# Sigma (fixed effects)",
       "zi" = ,
       "zero_inflated" = ,
       "fixed_zero_inflated" = ,
@@ -45,6 +47,8 @@ print_data_frame <- function(x, digits) {
       # clean smooth terms
       out[[i]]$Parameter <- gsub("^smooth_sd\\[(.*)\\]", "\\1", out[[i]]$Parameter)
       out[[i]]$Parameter <- gsub("^sds_", "\\1", out[[i]]$Parameter)
+      # SD
+      out[[i]]$Parameter <- gsub("(.*)(__Intercept|__zi_Intercept)(.*)", "\\1 (Intercept)\\3", gsub("^sd_(.*)", "SD \\1", out[[i]]$Parameter))
       # remove ".1" etc. suffix
       out[[i]]$Parameter <- gsub("(.*)(\\.)(\\d)$", "\\1 \\3", out[[i]]$Parameter)
       # remove "__zi"
@@ -56,7 +60,7 @@ print_data_frame <- function(x, digits) {
       cat("\n\n")
     }
 
-    cat(insight::format_table(out[[i]], digits = digits))
+    cat(insight::export_table(out[[i]], digits = digits))
     cat("\n")
   }
 }
