@@ -1,39 +1,29 @@
 ## ----setup, include=FALSE-----------------------------------------------------
-if (!requireNamespace("rstanarm", quietly = TRUE) ||
-      !requireNamespace("BayesFactor", quietly = TRUE) ||
-      !requireNamespace("emmeans", quietly = TRUE) ||
-      !requireNamespace("logspline", quietly = TRUE) ||
-      !requireNamespace("lme4", quietly = TRUE) ||
-      !requireNamespace("ggplot2", quietly = TRUE) ||
-      !requireNamespace("see", quietly = TRUE)
-      ) {
+library(knitr)
+options(knitr.kable.NA = '', digits = 2)
+knitr::opts_chunk$set(echo = TRUE,
+                      comment = ">",
+                      message = FALSE,
+                      warning = FALSE,
+                      dpi = 150)
+
+pkgs <- c("rstanarm", "BayesFactor", "emmeans", "logspline", "lme4", "ggplot2",
+          "see", "insight", "emmeans", "knitr", "effectsize", "bayestestR")
+if (!all(sapply(pkgs, require, quietly = TRUE, character.only = TRUE))) {
   knitr::opts_chunk$set(eval = FALSE)
-} else {
-  library(knitr)
-  library(insight)
-  library(bayestestR)
-  library(rstanarm)
-  library(BayesFactor)
-  library(emmeans)
-  
-  library(ggplot2)
-  library(see)
-  
-  options(knitr.kable.NA = '',
-          digits = 2)
-  opts_chunk$set(echo = TRUE,
-                 comment = ">",
-                 message = FALSE,
-                 warning = FALSE,
-                 dpi = 150)
+}
+
+set.seed(4)
+
+if (require("ggplot2") && require("see")) {
   theme_set(theme_modern())
-  set.seed(4)
 }
 
 ## ----deathsticks_fig, echo=FALSE, fig.cap="Bayesian analysis of the Students' (1908) Sleep data set.", fig.align='center', out.width="80%"----
 knitr::include_graphics("https://github.com/easystats/easystats/raw/master/man/figures/bayestestR/deathsticks.jpg")
 
 ## ----sleep_boxplot, echo=FALSE------------------------------------------------
+library(ggplot2)
 ggplot(sleep, aes(x = group, y = extra, fill= group)) +
   geom_boxplot() +
   theme_classic()
@@ -64,6 +54,7 @@ ggplot(mapping = aes(x_vals, d_vals, fill = in_null, group = range_groups)) +
   geom_area(color = "black", size = 1) +
   scale_fill_flat(name = "", labels = c("Alternative", "Null")) + 
   labs(x = "Drug effect", y = "Density") + 
+  coord_cartesian(ylim = c(0, 0.45)) +
   theme_modern() + 
   theme(legend.position = c(0.2, 0.8))
 
@@ -71,8 +62,8 @@ pnull <- diff(pnorm(null, sd = 2.5))
 prior_odds <- (1 - pnull) / pnull
 
 ## ----rstanarm_fit, echo=FALSE-------------------------------------------------
-
-model_prior <- bayestestR:::.update_to_priors.stanreg(model)
+library(bayestestR)
+model_prior <- unupdate(model)
 posterior <- insight::get_parameters(model)$group2
 prior <- insight::get_parameters(model_prior)$group2
 
@@ -84,6 +75,7 @@ ggplot(mapping = aes(x_vals, d_vals_post, fill = in_null, group = range_groups))
   geom_area(color = "black", size = 1) +
   scale_fill_flat(name = "", labels = c("Alternative", "Null")) + 
   labs(x = "Drug effect", y = "Density") + 
+  coord_cartesian(ylim = c(0, 0.45)) +
   theme_modern() + 
   theme(legend.position = c(0.2, 0.8))
 
@@ -105,6 +97,9 @@ print(My_first_BF)
 library(see)
 plot(My_first_BF)
 
+## -----------------------------------------------------------------------------
+effectsize::interpret_bf(My_first_BF$BF[2], include_value = TRUE)
+
 ## ---- eval=FALSE--------------------------------------------------------------
 #  My_second_BF <- bayesfactor_parameters(model, null = 0)
 #  My_second_BF
@@ -139,6 +134,22 @@ print(test_group2_right)
 ## -----------------------------------------------------------------------------
 plot(test_group2_right)
 
+## ----inteval_div, eval=FALSE--------------------------------------------------
+#  test_group2_dividing <- bayesfactor_parameters(model, null = c(-Inf, 0))
+#  test_group2_dividing
+
+## ----inteval_div2, echo=FALSE-------------------------------------------------
+test_group2_dividing <- bayesfactor_parameters(
+  data.frame(group2 = posterior),
+  data.frame(group2 = prior),
+  null = c(-Inf, 0)
+)
+
+print(test_group2_dividing)
+
+## -----------------------------------------------------------------------------
+plot(test_group2_dividing)
+
 ## ---- eval=FALSE--------------------------------------------------------------
 #  my_first_si <- si(model, BF = 1)
 #  my_first_si
@@ -157,15 +168,15 @@ plot(my_first_si)
 #  library(brms)
 #  
 #  m0 <- brm(Sepal.Length ~ 1, # intercept only model
-#            data = iris, save_all_pars = TRUE)
+#            data = iris, save_pars = save_pars(all = TRUE))
 #  m1 <- brm(Sepal.Length ~ Petal.Length,
-#            data = iris, save_all_pars = TRUE)
+#            data = iris, save_pars = save_pars(all = TRUE))
 #  m2 <- brm(Sepal.Length ~ Species,
-#            data = iris, save_all_pars = TRUE)
+#            data = iris, save_pars = save_pars(all = TRUE))
 #  m3 <- brm(Sepal.Length ~ Species + Petal.Length,
-#            data = iris, save_all_pars = TRUE)
+#            data = iris, save_pars = save_pars(all = TRUE))
 #  m4 <- brm(Sepal.Length ~ Species * Petal.Length,
-#            data = iris, save_all_pars = TRUE)
+#            data = iris, save_pars = save_pars(all = TRUE))
 
 ## ----brms_models_disp, eval=FALSE---------------------------------------------
 #  library(bayestestR)
@@ -198,6 +209,9 @@ update(comparison, reference = 3)
 ## ----update_models2-----------------------------------------------------------
 update(comparison, reference = 2)
 
+## -----------------------------------------------------------------------------
+as.matrix(comparison)
+
 ## ----lme4_models, eval=FALSE--------------------------------------------------
 #  library(lme4)
 #  
@@ -246,7 +260,7 @@ botanist_hypotheses <- c(
 
 ## ---- echo=FALSE--------------------------------------------------------------
 
-model_prior <- bayestestR:::.update_to_priors.stanreg(iris_model)
+model_prior <- unupdate(iris_model)
 
 botanist_BFs <- bayesfactor_restricted(iris_model, prior = model_prior, 
                                        hypothesis = botanist_hypotheses)
@@ -354,15 +368,16 @@ bayesfactor_parameters(groups_all, prior = model)
 ## ---- echo=FALSE--------------------------------------------------------------
 set.seed(1)
 
-## -----------------------------------------------------------------------------
-library(modelbased)
-
-estimate_contrasts(model, test = "bf")
+## ---- eval=FALSE--------------------------------------------------------------
+#  library(modelbased)
+#  
+#  estimate_contrasts(model, test = "bf")
 
 ## ---- eval=FALSE--------------------------------------------------------------
-#  contrasts(iris$Species) <- contr.sum
+#  df <- iris
+#  contrasts(df$Species) <- contr.sum
 #  
-#  fit_sum <- stan_glm(Sepal.Length ~ Species, data = iris,
+#  fit_sum <- stan_glm(Sepal.Length ~ Species, data = df,
 #                      prior = normal(0, c(1, 1), autoscale = FALSE),
 #                      prior_PD = TRUE, # sample priors
 #                      family = gaussian())
@@ -370,10 +385,11 @@ estimate_contrasts(model, test = "bf")
 #  pairs_sum <- pairs(emmeans(fit_sum, ~ Species))
 #  pairs_sum
 
-## ---- echo=FALSE--------------------------------------------------------------
-contrasts(iris$Species) <- contr.sum
+## ----echo=FALSE, message=FALSE, warning=FALSE---------------------------------
+df <- iris
+contrasts(df$Species)[, ] <- contr.sum(3)
 
-fit_sum <- stan_glm(Sepal.Length ~ Species, data = iris,
+fit_sum <- stan_glm(Sepal.Length ~ Species, data = df,
                     prior = normal(0, c(1, 1), autoscale = FALSE),
                     prior_PD = TRUE, # sample priors
                     family = gaussian(),
@@ -391,16 +407,14 @@ ggplot(stack(em_pairs_samples), aes(x = values, fill = ind)) +
   labs(x = "prior difference values") + 
   theme(legend.position = "none")
 
-## -----------------------------------------------------------------------------
-contrasts(iris$Species) <- contr.bayes
+## ---- eval=FALSE--------------------------------------------------------------
+#  contrasts(df$Species) <- contr.bayes
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  options(contrasts = c('contr.bayes', 'contr.poly'))
 
 ## ---- eval=FALSE--------------------------------------------------------------
-#  contrasts(iris$Species) <- contr.bayes
-#  
-#  fit_bayes <- stan_glm(Sepal.Length ~ Species, data = iris,
+#  fit_bayes <- stan_glm(Sepal.Length ~ Species, data = df,
 #                        prior = normal(0, c(1, 1), autoscale = FALSE),
 #                        prior_PD = TRUE, # sample priors
 #                        family = gaussian())
@@ -409,9 +423,9 @@ contrasts(iris$Species) <- contr.bayes
 #  pairs_bayes
 
 ## ---- echo=FALSE--------------------------------------------------------------
-contrasts(iris$Species) <- contr.bayes
+contrasts(df$Species)[, ] <- contr.bayes(3)
 
-fit_bayes <- stan_glm(Sepal.Length ~ Species, data = iris,
+fit_bayes <- stan_glm(Sepal.Length ~ Species, data = df,
                       prior = normal(0, c(1, 1), autoscale = FALSE),
                       prior_PD = TRUE, # sample priors
                       family = gaussian(),
@@ -443,9 +457,9 @@ hyp <- c(
 )
 
 ## ---- eval=FALSE--------------------------------------------------------------
-#  contrasts(iris$Species) <- contr.sum
+#  contrasts(df$Species) <- contr.sum
 #  
-#  fit_sum <- stan_glm(Sepal.Length ~ Species, data = iris,
+#  fit_sum <- stan_glm(Sepal.Length ~ Species, data = df,
 #                      prior = normal(0, c(1, 1), autoscale = FALSE),
 #                      family = gaussian())
 #  
@@ -454,9 +468,9 @@ hyp <- c(
 #  bayesfactor_restricted(em_sum, fit_sum, hypothesis = hyp)
 
 ## ---- echo=FALSE--------------------------------------------------------------
-contrasts(iris$Species) <- contr.sum
+contrasts(df$Species)[, ] <- contr.sum(3)
 
-fit_sum <- stan_glm(Sepal.Length ~ Species, data = iris,
+fit_sum <- stan_glm(Sepal.Length ~ Species, data = df,
                     prior = normal(0, c(1, 1), autoscale = FALSE),
                     family = gaussian(),
                     refresh = 0)
@@ -466,9 +480,9 @@ em_sum <- emmeans(fit_sum, ~ Species) # the posterior marginal means
 bayesfactor_restricted(em_sum, fit_sum, hypothesis = hyp)
 
 ## ---- eval=FALSE--------------------------------------------------------------
-#  contrasts(iris$Species) <- contr.bayes
+#  contrasts(df$Species) <- contr.bayes
 #  
-#  fit_bayes <- stan_glm(Sepal.Length ~ Species, data = iris,
+#  fit_bayes <- stan_glm(Sepal.Length ~ Species, data = df,
 #                        prior = normal(0, c(1, 1), autoscale = FALSE),
 #                        family = gaussian())
 #  
@@ -477,9 +491,9 @@ bayesfactor_restricted(em_sum, fit_sum, hypothesis = hyp)
 #  bayesfactor_restricted(em_bayes, fit_sum, hypothesis = hyp)
 
 ## ---- echo=FALSE--------------------------------------------------------------
-contrasts(iris$Species) <- contr.bayes
+contrasts(df$Species)[, ] <- contr.bayes(3)
 
-fit_bayes <- stan_glm(Sepal.Length ~ Species, data = iris,
+fit_bayes <- stan_glm(Sepal.Length ~ Species, data = df,
                       prior = normal(0, c(1, 1), autoscale = FALSE),
                       family = gaussian(),
                       refresh = 0)
