@@ -1,11 +1,5 @@
 if (require("logspline") && require("KernSmooth") && require("mclust")) {
-  context("estimate_density")
-
   test_that("estimate_density", {
-    library(logspline)
-    library(KernSmooth)
-    library(mclust)
-
     set.seed(333)
     x <- distribution_normal(500, 1)
 
@@ -19,4 +13,4 @@ if (require("logspline") && require("KernSmooth") && require("mclust")) {
     testthat::expect_equal(mean(density_kernel$y - density_KernSmooth$y), 0, tol = 0.1)
     testthat::expect_equal(mean(density_kernel$y - density_mixture$y), 0, tol = 0.1)
   })
-}
\ No newline at end of file
+}
